
.. automodule:: bci_framework.extensions.visualizations
   :members:
   :no-undoc-members:
   :no-show-inheritance:

Submodules
----------

.. toctree::
   :maxdepth: 4

   bci_framework.extensions.visualizations.eeg_stream
